@@ -184,7 +184,7 @@ static struct {
     NULL,
     NULL,
     NULL,
-    LOG_PRIMASK,
+    LOG_UPTO(LOG_DEBUG),
     0,
     FALSE
 };
@@ -615,9 +615,10 @@ void closelog(void)
         free(ctx.levelmap);
         ctx.levelmap = NULL;
     }
-    ctx.maskpri = LOG_PRIMASK;
+    ctx.maskpri = LOG_UPTO(LOG_DEBUG);
     ctx.logopt = 0;
     ctx.delayopen = FALSE;
+    return;
 }
 
 int setlogmask(int maskpri)
@@ -672,7 +673,7 @@ void vsyslog(int priority, const char *fmt, va_list args)
 
     /* strip off facility */
     priority &= LOG_PRIMASK;
-    fsldebug(L2_LEVEL_DEBUG, "prioriy  =0x%.8lx, ctx.maskpri=0x%.8lx  ", (unsigned long)priority, (unsigned long)ctx.maskpri);
+    fsldebug(L2_LEVEL_DEBUG, "priority =0x%.8lx, ctx.maskpri=0x%.8lx  ", (unsigned long)priority, (unsigned long)ctx.maskpri);
 
     /* check against maskpri */
     if ((LOG_MASK(priority) & ctx.maskpri) == 0) {
