@@ -82,7 +82,7 @@ static l2_result_t hook_create(l2_context_t *ctx, l2_channel_t *ch)
     cfg->cpChannel  = strdup("#l2");
     cfg->bJoin      = 1;
     cfg->cpHost     = NULL;
-    cfg->cpPort     = strdup("6667");
+    cfg->cpPort     = strdup("6667"); /*FIXME[thl] better use getservbyname()*/
     cfg->nTimeout   = 30;
     cfg->saaServer  = NULL;
     cfg->saServer   = NULL;
